==> firebase_in_app_messaging-0.6.0%2B7.tar.gz: CHANGELOG.md <==
## 0.6.0+7

 - **FIX**: issue where Boolean value was always `true` for `setMessagesSuppressed ()` & `setAutomaticDataCollectionEnabled()` on iOS. (#7954). ([e397add5](https://github.com/FirebaseExtended/flutterfire/commit/e397add52fc30d08bccad000237962ca3c903e49))
 - **FIX**: setup missing Firebase internal SDK headers (#7513). ([4c9d84cd](https://github.com/FirebaseExtended/flutterfire/commit/4c9d84cdc3f491c7d9c1421e7651742e5c2ccc1e))

## 0.6.0+6

 - **FIX**: bump Android `compileSdkVersion` to 31 (#7726). ([a9562bac](https://github.com/FirebaseExtended/flutterfire/commit/a9562bac60ba927fb3664a47a7f7eaceb277dca6))
 - **FIX**: lazily get the default `FirebaseInAppMessaging` instance on Android to allow for Firebase initialization via Dart only. ([88cfa0c8](https://github.com/FirebaseExtended/flutterfire/commit/88cfa0c81543f639eb14c75a0d655806d9683bbf))
 - **FIX**: issue where Dart only initialization did not function correctly on iOS. ([5c6feb72](https://github.com/FirebaseExtended/flutterfire/commit/5c6feb72c446cbe9632ff4ad6b963b63d92aec76))

## 0.6.0+5

 - Update a dependency to the latest release.

## 0.6.0+4

 - Update a dependency to the latest release.

## 0.6.0+3

 - Update a dependency to the latest release.

## 0.6.0+2

 - Update a dependency to the latest release.

## 0.6.0+1

 - Update a dependency to the latest release.

## 0.6.0

 - **FEAT**: Add plugin federation (#7345).

## 0.5.0+14

 - Update a dependency to the latest release.

## 0.5.0+13

 - Update a dependency to the latest release.

## 0.5.0+12

 - **REFACTOR**: update example app to use latest Firebase Analytics plugin APIs.

## 0.5.0+11

 - **REFACTOR**: remove deprecated Flutter Android v1 Embedding usages, including in example app (#7158).

## 0.5.0+10

 - Update a dependency to the latest release.

## 0.5.0+9

 - Update a dependency to the latest release.

## 0.5.0+8

 - Update a dependency to the latest release.

## 0.5.0+7

 - Update a dependency to the latest release.

## 0.5.0+6

 - Update a dependency to the latest release.

## 0.5.0+5

 - Update a dependency to the latest release.

## 0.5.0+4

 - Update a dependency to the latest release.

## 0.5.0+3

 - **DOCS**: Add missing homepage/repository links (#6054).

## 0.5.0+2

 - Update a dependency to the latest release.

## 0.5.0+1

 - Update a dependency to the latest release.

## 0.5.0

 - Migrate to null safety.

## 0.4.0+1

 - Update a dependency to the latest release.

## 0.4.0

 - This version is not null-safe but has been created to allow compatibility with other null-safe FlutterFire packages such as `firebase_core`.

## 0.3.0

 - **FEAT**: bump firebase-android-sdk BoM to 25.13.0.
 - **CHORE**: harmonize dependencies and version handling.
 - **BREAKING** **FEAT**: forward port to firebase-ios-sdk v7.3.0.
   - Due to this SDK upgrade, iOS 10 is now the minimum supported version by FlutterFire. Please update your build target version.

## 0.2.3

 - **FEAT**: bump android `com.android.tools.build` & `'com.google.gms:google-services` versions (#4269).
 - **CHORE**: publish packages.
 - **CHORE**: bump gradle wrapper to 5.6.4 (#4158).

## 0.2.2

 - **FEAT**: bump compileSdkVersion to 29 (#3975).
 - **FEAT**: bump `compileSdkVersion` to 29 in preparation for upcoming Play Store requirement.
 - **CHORE**: publish packages.
 - **CHORE**: publish packages.

## 0.2.1

 - **FEAT**: bump compileSdkVersion to 29 (#3975).
 - **FEAT**: update Firebase iOS SDK version to 6.33.0 (from 6.26.0).

## 0.2.0+3

 - Update a dependency to the latest release.

## 0.2.0+2

 - **FIX**: local dependencies in example apps (#3319).
 - **CHORE**: fix pod install error on example FIAM app (#3116).

## 0.2.0+1

* Fixed issue #3227 (Invalid podspec).

## 0.2.0

* Depend on `firebase_core` pre-release.
* Firebase iOS SDK versions are now locked to use the same version defined in
  `firebase_core`.
* Firebase Android SDK versions are now using the Firebase Bill of Materials (BoM)
  to specify individual SDK versions. BoM version is also sourced from
  `firebase_core`.
* Allow iOS to be imported as a module.
* Updated package of Android from `com.example.firebase_in_app_messaging` to
  `io.flutter.plugins.firebase.inappmessaging`.

## 0.1.2

* Update lower bound of dart dependency to 2.0.0.

## 0.1.1+3

* Replace deprecated `getFlutterEngine` call on Android.

## 0.1.1+2

* Make the pedantic dev_dependency explicit.

## 0.1.1+1

* Remove the deprecated `author:` field from pubspec.yaml
* Migrate the plugin to the pubspec platforms manifest.
* Bump the minimum Flutter version to 1.10.0.

## 0.1.1

* Updated the plugin API to v2.

## 0.1.0

* Updated README instructions for contributing for consistency with other Flutterfire plugins.

## 0.0.1+4

* Update example app with correct const constructors.

## 0.0.1+3

* Update AGP, gradle and inappmessaging-display versions on Android.

## 0.0.1+2

* Remove dependency `androidx.annotation:annotation:1.0.0`.

## 0.0.1+1

* Update google-services Android gradle plugin to 4.3.0 in documentation and examples.

## 0.0.1

* Initial release.

==> firebase_in_app_messaging-0.7.0%2B7.tar.gz: CHANGELOG.md <==
## 0.7.0+7

 - **FIX**: in app messages were suppressed on iOS ([#9959](https://github.com/firebase/flutterfire/issues/9959)). ([929e3686](https://github.com/firebase/flutterfire/commit/929e3686b76c1ce57cf87f19498cd52fb577a8c6))

## 0.7.0+6

 - Update a dependency to the latest release.

## 0.7.0+5

 - Update a dependency to the latest release.

## 0.7.0+4

 - Update a dependency to the latest release.

## 0.7.0+3

 - Update a dependency to the latest release.

## 0.7.0+2

 - Update a dependency to the latest release.

## 0.7.0+1

 - Update a dependency to the latest release.

## 0.7.0

> Note: This release has breaking changes.

 - **BREAKING** **FEAT**: Firebase iOS SDK version: `10.0.0` ([#9708](https://github.com/firebase/flutterfire/issues/9708)). ([9627c56a](https://github.com/firebase/flutterfire/commit/9627c56a37d657d0250b6f6b87d0fec1c31d4ba3))

## 0.6.0+27

 - Update a dependency to the latest release.

## 0.6.0+26

 - Update a dependency to the latest release.

## 0.6.0+25

 - Update a dependency to the latest release.

## 0.6.0+24

 - Update a dependency to the latest release.

## 0.6.0+23

 - **REFACTOR**: update deprecated `Tasks.call()` to `TaskCompletionSource` API ([#9407](https://github.com/firebase/flutterfire/pull/9407)). ([837d68ea](https://github.com/firebase/flutterfire/commit/bb9b3b23c683d28730a1952f54384caed78674d7))
 - Update a dependency to the latest release.

## 0.6.0+22

 - Update a dependency to the latest release.

## 0.6.0+21

 - Update a dependency to the latest release.

## 0.6.0+20

 - Update a dependency to the latest release.

## 0.6.0+19

 - Update a dependency to the latest release.

## 0.6.0+18

 - **FIX**: bump `firebase_core_platform_interface` version to fix previous release. ([bea70ea5](https://github.com/firebase/flutterfire/commit/bea70ea5cbbb62cbfd2a7a74ae3a07cb12b3ee5a))

## 0.6.0+17

 - Update a dependency to the latest release.

## 0.6.0+16

 - **REFACTOR**: use "firebase" instead of "FirebaseExtended" as organisation in all links for this repository (#8791). ([d90b8357](https://github.com/firebase/flutterfire/commit/d90b8357db01d65e753021358668f0b129713e6b))
 - **DOCS**: point to "firebase.google" domain for hyperlinks in the usage section of `README.md` files (for the missing packages) (#8818). ([5bda8c92](https://github.com/firebase/flutterfire/commit/5bda8c92be1651a941d1285d36e885ee0b967b11))

## 0.6.0+15

 - **REFACTOR**: use `firebase.google.com` link for `homepage` in `pubspec.yaml` (#8734). ([9ce47865](https://github.com/firebase/flutterfire/commit/9ce47865e4fcba0aaf1a4558ba7ede13abcde21d))

## 0.6.0+14

 - Update a dependency to the latest release.

## 0.6.0+13

 - Update a dependency to the latest release.

## 0.6.0+12

 - Update a dependency to the latest release.

## 0.6.0+11

 - Update a dependency to the latest release.

## 0.6.0+10

 - Update a dependency to the latest release.

## 0.6.0+9

 - **FIX**: update all Dart SDK version constraints to Dart >= 2.16.0 (#8184). ([df4a5bab](https://github.com/firebase/flutterfire/commit/df4a5bab3c029399b4f257a5dd658d302efe3908))

## 0.6.0+8

 - Update a dependency to the latest release.

## 0.6.0+7

 - **FIX**: issue where Boolean value was always `true` for `setMessagesSuppressed ()` & `setAutomaticDataCollectionEnabled()` on iOS. (#7954). ([e397add5](https://github.com/firebase/flutterfire/commit/e397add52fc30d08bccad000237962ca3c903e49))
 - **FIX**: setup missing Firebase internal SDK headers (#7513). ([4c9d84cd](https://github.com/firebase/flutterfire/commit/4c9d84cdc3f491c7d9c1421e7651742e5c2ccc1e))

## 0.6.0+6

 - **FIX**: bump Android `compileSdkVersion` to 31 (#7726). ([a9562bac](https://github.com/firebase/flutterfire/commit/a9562bac60ba927fb3664a47a7f7eaceb277dca6))
 - **FIX**: lazily get the default `FirebaseInAppMessaging` instance on Android to allow for Firebase initialization via Dart only. ([88cfa0c8](https://github.com/firebase/flutterfire/commit/88cfa0c81543f639eb14c75a0d655806d9683bbf))
 - **FIX**: issue where Dart only initialization did not function correctly on iOS. ([5c6feb72](https://github.com/firebase/flutterfire/commit/5c6feb72c446cbe9632ff4ad6b963b63d92aec76))

## 0.6.0+5

 - Update a dependency to the latest release.

## 0.6.0+4

 - Update a dependency to the latest release.

## 0.6.0+3

 - Update a dependency to the latest release.

## 0.6.0+2

 - Update a dependency to the latest release.

## 0.6.0+1

 - Update a dependency to the latest release.

## 0.6.0

 - **FEAT**: Add plugin federation (#7345).

## 0.5.0+14

 - Update a dependency to the latest release.

## 0.5.0+13

 - Update a dependency to the latest release.

## 0.5.0+12

 - **REFACTOR**: update example app to use latest Firebase Analytics plugin APIs.

## 0.5.0+11

 - **REFACTOR**: remove deprecated Flutter Android v1 Embedding usages, including in example app (#7158).

## 0.5.0+10

 - Update a dependency to the latest release.

## 0.5.0+9

 - Update a dependency to the latest release.

## 0.5.0+8

 - Update a dependency to the latest release.

## 0.5.0+7

 - Update a dependency to the latest release.

## 0.5.0+6

 - Update a dependency to the latest release.

## 0.5.0+5

 - Update a dependency to the latest release.

## 0.5.0+4

 - Update a dependency to the latest release.

## 0.5.0+3

 - **DOCS**: Add missing homepage/repository links (#6054).

## 0.5.0+2

 - Update a dependency to the latest release.

## 0.5.0+1

 - Update a dependency to the latest release.

## 0.5.0

 - Migrate to null safety.

## 0.4.0+1

 - Update a dependency to the latest release.

## 0.4.0

 - This version is not null-safe but has been created to allow compatibility with other null-safe FlutterFire packages such as `firebase_core`.

## 0.3.0

 - **FEAT**: bump firebase-android-sdk BoM to 25.13.0.
 - **CHORE**: harmonize dependencies and version handling.
 - **BREAKING** **FEAT**: forward port to firebase-ios-sdk v7.3.0.
   - Due to this SDK upgrade, iOS 10 is now the minimum supported version by FlutterFire. Please update your build target version.

## 0.2.3

 - **FEAT**: bump android `com.android.tools.build` & `'com.google.gms:google-services` versions (#4269).
 - **CHORE**: publish packages.
 - **CHORE**: bump gradle wrapper to 5.6.4 (#4158).

## 0.2.2

 - **FEAT**: bump compileSdkVersion to 29 (#3975).
 - **FEAT**: bump `compileSdkVersion` to 29 in preparation for upcoming Play Store requirement.
 - **CHORE**: publish packages.
 - **CHORE**: publish packages.

## 0.2.1

 - **FEAT**: bump compileSdkVersion to 29 (#3975).
 - **FEAT**: update Firebase iOS SDK version to 6.33.0 (from 6.26.0).

## 0.2.0+3

 - Update a dependency to the latest release.

## 0.2.0+2

 - **FIX**: local dependencies in example apps (#3319).
 - **CHORE**: fix pod install error on example FIAM app (#3116).

## 0.2.0+1

* Fixed issue #3227 (Invalid podspec).

## 0.2.0

* Depend on `firebase_core` pre-release.
* Firebase iOS SDK versions are now locked to use the same version defined in
  `firebase_core`.
* Firebase Android SDK versions are now using the Firebase Bill of Materials (BoM)
  to specify individual SDK versions. BoM version is also sourced from
  `firebase_core`.
* Allow iOS to be imported as a module.
* Updated package of Android from `com.example.firebase_in_app_messaging` to
  `io.flutter.plugins.firebase.inappmessaging`.

## 0.1.2

* Update lower bound of dart dependency to 2.0.0.

## 0.1.1+3

* Replace deprecated `getFlutterEngine` call on Android.

## 0.1.1+2

* Make the pedantic dev_dependency explicit.

## 0.1.1+1

* Remove the deprecated `author:` field from pubspec.yaml
* Migrate the plugin to the pubspec platforms manifest.
* Bump the minimum Flutter version to 1.10.0.

## 0.1.1

* Updated the plugin API to v2.

## 0.1.0

* Updated README instructions for contributing for consistency with other Flutterfire plugins.

## 0.0.1+4

* Update example app with correct const constructors.

## 0.0.1+3

* Update AGP, gradle and inappmessaging-display versions on Android.

## 0.0.1+2

* Remove dependency `androidx.annotation:annotation:1.0.0`.

## 0.0.1+1

* Update google-services Android gradle plugin to 4.3.0 in documentation and examples.

## 0.0.1

* Initial release.
